@@ -250,6 +250,8 @@ def doReset(logfilename):
 
 @task()
 def combineResults(allout):
+    if not os.isdir(fetch_media_resource("Results/Buckeye")):
+        os.mkdir(fetch_media_resource("Results/Buckeye"))
     with open(fetch_media_resource("Results/Buckeye/analysis.txt"),'w') as f:
         f.write("\t".join(allout[0][0].keys()))
         f.write("\n")
@@ -326,10 +328,11 @@ def doBasicAnalysis(logfilename,form):
     sp = [str(x) for x in Speaker.objects.all() if str(x) != 's35']
     if settings.DEBUG:
         sp = Speaker.objects.filter(Number = 's03')
+        AnalyzeSpeaker(words,sp[0],form)
     #for s in sp:
     #    AnalyzeSpeaker.delay(words, s,form)
-    res = chord((AnalyzeSpeaker.s(words, s, form) for s in sp), combineResults.s())()
-    res.get()
+    else:
+        res = chord((AnalyzeSpeaker.s(words, s, form) for s in sp), combineResults.s())()
 
 #@task_success.connect(sender=doBasicAnalysis)
 #def consolidateResultFiles():
